A simple interface for building and using cumulative
distribution functions and quantile functions.

A common use of a cumulative distribution
function is to map a uniform random variable into a 
nonuniform distribution.

An inverse cumulative distribution function or quantile
function does the opposite - it can map a nonuniformally
distributed random variable into a uniformly distributed
space.

These two components can be used together to create
a mapping from one non-uniform space to a different one.

In this module, the uniform side of a distribution
function has a domain of [0, 1].  The non-uniform side
may have any range.